/*
 * Copyright (c) 2011 - 2021 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <app_core_efl_base.hh>

#include "app_internal.h"
#include "common_private.hh"

using namespace tizen_cpp;

namespace {

/* LCOV_EXCL_START */
app_device_orientation_e AppCoreRmConvert(int rm) {
  switch (rm) {
  case AppCoreBase::ROTATION_PORTRAIT_NORMAL:
    return APP_DEVICE_ORIENTATION_0;
  case AppCoreBase::ROTATION_PORTRAIT_REVERSE:
    return APP_DEVICE_ORIENTATION_180;
  case AppCoreBase::ROTATION_LANDSCAPE_NORMAL:
    return APP_DEVICE_ORIENTATION_270;
  case AppCoreBase::ROTATION_LANDSCAPE_REVERSE:
    return APP_DEVICE_ORIENTATION_90;
  default:
    return APP_DEVICE_ORIENTATION_0;
  }
}
/* LCOV_EXCL_STOP */

}  // namespace

API app_device_orientation_e app_get_device_orientation(void) {
  app_device_orientation_e dev_orientation = APP_DEVICE_ORIENTATION_0;

  try {
    AppCoreBase::RotationState s = AppCoreBase::GetRotationState();
    dev_orientation = AppCoreRmConvert(s);
  } catch (const std::runtime_error& e) {
    return APP_DEVICE_ORIENTATION_0;
  }

  return dev_orientation;
}
