/*
 * Copyright (c) 2011 - 2021 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <Elementary.h>

#include "app_extension.h"
#include "common_private.hh"

API void* app_get_preinitialized_window(const char* win_name) {
  void* win = elm_win_precreated_object_get();
  if (win == nullptr)
    return nullptr;

  if (win_name != nullptr) {
    const Evas* e = evas_object_evas_get(static_cast<Evas_Object*>(win));
    if (e != nullptr) {
      Ecore_Evas* ee = ecore_evas_ecore_evas_get(e);
      if (ee != nullptr)
        ecore_evas_name_class_set(ee, win_name, win_name);
    }
  }

  elm_win_precreated_object_set(nullptr);
  return win;
}

API void* app_get_preinitialized_background(void) {
  void* background = elm_bg_precreated_object_get();
  if (background == nullptr)
    return nullptr;

  elm_bg_precreated_object_set(nullptr);
  return background;
}

API void* app_get_preinitialized_conformant(void) {
  void* conformant = elm_conformant_precreated_object_get();
  if (conformant == nullptr)
    return nullptr;

  elm_conformant_precreated_object_set(nullptr);
  return conformant;
}
